Openstack Config
================

This workspace demonstrates the use of cfgs in a PinFile.  The PinFile provisions an openstack cluster, at which point the variables defined in the cfgs section are used
